@@ -1,6 +1,7 @@
 from django.template import RequestContext
+from django.shortcuts import render_to_response
 from basic_cms.testproj.documents.models import Document
-from basic_cms.http import auto_render
+
 
 def document_view(request, *args, **kwargs):
     context = RequestContext(request, kwargs)
@@ -11,6 +12,4 @@ def document_view(request, *args, **kwargs):
         document = Document.objects.get(pk=int(kwargs['document_id']))
         context['document'] = document
     context['in_document_view'] = True
-    return 'pages/examples/index.html', context
-
-document_view = auto_render(document_view)
+    return render_to_response('pages/examples/index.html', context, context_instance=RequestContext(request))
